# [Zope-tests] FAILED : Zope 3.4 Known Good Set / py2.4-64bit-linux

buildbot at pov.lt buildbot at pov.lt
Tue Feb 1 21:05:11 EST 2011

- Previous message: [Zope-tests] OK : winbot / ZODB_dev py_265_win64
- Next message: [Zope-tests] OK : winbot / ZODB_dev py_270_win32
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

    FAILED : Zope 3.4 Known Good Set / py2.4-64bit-linux
    Build: https://zope3.pov.lt/buildbot/builders/py2.4-64bit-linux/builds/906

    Build Reason: The Nightly scheduler named 'nightly1' triggered this build

    Build Source Stamp: HEAD

    Blamelist:

    Buildbot: https://zope3.pov.lt/buildbot/

- Previous message: [Zope-tests] OK : winbot / ZODB_dev py_265_win64
- Next message: [Zope-tests] OK : winbot / ZODB_dev py_270_win32
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

More information about the Zope-tests mailing list